@@ -7,6 +7,10 @@
 #include "numpy/ndarraytypes.h"
 
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 typedef struct {
     int key_len;  /* number of identities used */
     /* Buckets stores: val1, key1[0], key1[1], ..., val2, key2[0], ... */
@@ -14,11 +18,7 @@ typedef struct {
     npy_intp size;  /* current size */
     npy_intp nelem;  /* number of elements */
 #ifdef Py_GIL_DISABLED
-#if PY_VERSION_HEX < 0x30d00b3
-#error "GIL-disabled builds require Python 3.13.0b3 or newer"
-#else
-    PyMutex mutex;
-#endif
+    void *mutex;
 #endif
 } PyArrayIdentityHash;
 
@@ -36,4 +36,8 @@ PyArrayIdentityHash_New(int key_len);
 NPY_NO_EXPORT void
 PyArrayIdentityHash_Dealloc(PyArrayIdentityHash *tb);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif  /* NUMPY_CORE_SRC_COMMON_NPY_NPY_HASHTABLE_H_ */
